use std::str::Lines;

pub enum ServiceType {
    APP,
    POSTGRES,
    REDIS,
    MYSQL,
}

pub fn check_project_exists(project_name: &String) -> bool {
    let mut channel = crate::ssh::connect();
    let result = crate::ssh::exec(&mut channel, "sudo dokku apps:list", true);
    let projects_lines: Lines = result.lines();
    let projects: Vec<&str> = projects_lines.collect();

    crate::ssh::close(channel);

    if projects.iter().any(|&project| project == project_name) {
        return true;
    }
    return false;
}

fn get_service_type(service_type: ServiceType) -> String {
    match service_type {
        ServiceType::APP => String::from("apps"),
        ServiceType::POSTGRES => String::from("postgres"),
        ServiceType::REDIS => String::from("redis"),
        _ => String::from("mysql"),
    }
}

pub fn create_service(service_type: ServiceType, project_name: &String) -> bool {
    let mut channel = crate::ssh::connect();
    let mut _service_type = String::new();
    let _service_type: String = get_service_type(service_type);
    let command = format!("sudo dokku {}:create {}", _service_type, project_name);

    crate::ssh::exec(&mut channel, command.as_str(), false);
    crate::ssh::close(channel);
    true
}

pub fn link_service(service_type: ServiceType, project_name: &String) -> bool {
    let mut channel = crate::ssh::connect();
    let mut _service_type = String::new();
    let _service_type: String = get_service_type(service_type);
    crate::ssh::exec(&mut channel, format!("sudo dokku {}:link {}", _service_type, project_name).as_str(), false);
    crate::ssh::close(channel);
    true
}

pub fn force_ports(project_name: &String) {
    let mut channel = crate::ssh::connect();
    crate::ssh::exec(&mut channel, format!("sudo dokku proxy:ports-set {} http:80:80", project_name).as_str(), false);
    crate::ssh::close(channel);
}

pub fn mount(project_name: &String) {
    let mut channel = crate::ssh::connect();
    crate::ssh::exec(&mut channel, format!("sudo storage:mount {} /var/lib/dokku/data/storage/{}:/var/www/html/wp-content/uploads", project_name, project_name).as_str(), false);
    crate::ssh::close(channel);
}

pub fn set_domains(project_name: &String, domains: &String) {
    let mut channel = crate::ssh::connect();
    crate::ssh::exec(&mut channel, format!("sudo domains:set {} {}", project_name, domains).as_str(), false);
    crate::ssh::close(channel);
}