use ssh2::{Session};
use ssh2::Channel;
use std::io::prelude::*;
use std::net::TcpStream;
use std::path::Path;
use structopt::StructOpt;

pub fn exec(channel: &mut Channel, command: &str, silent: bool) -> String {
    if silent == false {
        println!("Exec {}", command);
    }
    channel.exec(command).unwrap();
    let mut s = String::new();
    channel.read_to_string(&mut s).unwrap();
    if silent == false {
        println!("{}", s);
    }
    s
}

pub fn connect() -> Channel {
    // let args: Vec<String> = env::args().collect();
    // let private_key_path = String::from(&args[1]);
    // let mut server_host = String::from(&args[2]);
    let args = crate::Args::from_args();
    let private_key_path = args.private_key_path;
    let mut server_host = args.host;

    server_host.push_str(":22");

    let tcp = TcpStream::connect(server_host.as_str()).unwrap();
    let mut sess = Session::new().unwrap();
    sess.set_tcp_stream(tcp);
    sess.handshake().unwrap();

    let private_key: &Path = Path::new(private_key_path.as_str());
    let pubkey_result = sess.userauth_pubkey_file("ubuntu", None, private_key, None);
    match pubkey_result {
        Ok(_) => {},
        Err(error) => {
            println!("Your private key seems to be protected by a passphrase, this is not supported at the moment, sorry.");
            panic!("{}", error);
        }
    }
    sess.channel_session().unwrap()
}

pub fn close(mut channel: Channel) {
    channel.wait_close().ok();
    channel.exit_status().unwrap();
}
